@@ -1,10 +1,9 @@
-'use strict';
-const style = require('.');
+import ansiStyles from './index.js';
 
 const width = 55;
 let lineLength = 0;
 
-for (const [key, value] of Object.entries(style)) {
+for (const [key, value] of Object.entries(ansiStyles)) {
 	let code = value.open;
 	let projectedLength = lineLength + key.length + 1;
 
@@ -13,7 +12,7 @@ for (const [key, value] of Object.entries(style)) {
 	}
 
 	if (/^bg[^B]/.test(key)) {
-		code = style.black.open + code;
+		code = ansiStyles.black.open + code;
 	}
 
 	if (width < projectedLength) {
@@ -22,6 +21,6 @@ for (const [key, value] of Object.entries(style)) {
 		projectedLength = key.length + 1;
 	}
 
-	process.stdout.write(code + key + style.reset.close + ' ');
+	process.stdout.write(code + key + ansiStyles.reset.close + ' ');
 	lineLength = projectedLength;
 }
